@@ -10,20 +10,20 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.01';
-$DATE = '2003/07/04';
+$VERSION = '0.02';
+$DATE = '2003/07/11';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_PM2File.pm' => [qw(0.01 2003/07/04), 'revised 0.03'],
-    'MANIFEST' => [qw(0.01 2003/07/04), 'generated, replaces 0.03'],
-    'Makefile.PL' => [qw(0.01 2003/07/04), 'generated, replaces 0.03'],
-    'README' => [qw(0.01 2003/07/04), 'generated, replaces 0.03'],
-    'lib/File/PM2File.pm' => [qw(1.1 2003/07/04), 'revised 1.09'],
-    't/File/PM2File.d' => [qw(0.01 2003/07/04), 'new'],
-    't/File/PM2File.pm' => [qw(0.01 2003/07/04), 'new'],
-    't/File/PM2File.t' => [qw(0.07 2003/07/04), 'revised 0.06'],
+    'lib/Docs/Site_SVD/File_PM2File.pm' => [qw(0.02 2003/07/11), 'revised 0.01'],
+    'MANIFEST' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
+    'Makefile.PL' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
+    'README' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
+    'lib/File/PM2File.pm' => [qw(1.11 2003/07/11), 'revised 1.1'],
+    't/File/PM2File.d' => [qw(0.01 2003/07/07), 'unchanged'],
+    't/File/PM2File.pm' => [qw(0.01 2003/06/07), 'unchanged'],
+    't/File/PM2File.t' => [qw(0.01 2003/07/07), 'unchanged'],
 
 );
 
@@ -48,13 +48,13 @@ use vars qw(%INVENTORY);
 
  for
 
-  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
+  File::PM2File - Convert PM specifications to file specifications
 
- Revision: -
+ Revision: A
 
- Version: 0.01
+ Version: 0.02
 
- Date: 2003/07/04
+ Date: 2003/07/11
 
  Prepared for: General Public 
 
@@ -88,7 +88,7 @@ to the file specification for the current site operating system.
 
 =head2 1.3 Document overview.
 
-This document releases File::PM2File version 0.01
+This document releases File::PM2File version 0.02
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -104,8 +104,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/File-PM2File-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.01
+   http://www.softwarediamonds/packages/File-PM2File-0.02
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.02
 
 
 Restrictions regarding duplication and license provisions
@@ -173,24 +173,18 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_PM2File.pm                            0.01    2003/07/04 revised 0.03
- MANIFEST                                                     0.01    2003/07/04 generated, replaces 0.03
- Makefile.PL                                                  0.01    2003/07/04 generated, replaces 0.03
- README                                                       0.01    2003/07/04 generated, replaces 0.03
- lib/File/PM2File.pm                                          1.1     2003/07/04 revised 1.09
- t/File/PM2File.d                                             0.01    2003/07/04 new
- t/File/PM2File.pm                                            0.01    2003/07/04 new
- t/File/PM2File.t                                             0.07    2003/07/04 revised 0.06
+ lib/Docs/Site_SVD/File_PM2File.pm                            0.02    2003/07/11 revised 0.01
+ MANIFEST                                                     0.02    2003/07/11 generated, replaces 0.01
+ Makefile.PL                                                  0.02    2003/07/11 generated, replaces 0.01
+ README                                                       0.02    2003/07/11 generated, replaces 0.01
+ lib/File/PM2File.pm                                          1.11    2003/07/11 revised 1.1
+ t/File/PM2File.d                                             0.01    2003/07/07 unchanged
+ t/File/PM2File.pm                                            0.01    2003/06/07 unchanged
+ t/File/PM2File.t                                             0.01    2003/07/07 unchanged
 
 
 =head2 3.3 Changes
 
-The file names from 0.03 were changed as follows:
-
-  
-   return if $file =~ s=FileUtil/FileUtil=PM2File=;
-  return if $file =~ s=FileUtil=PM2File=;
-
 Changes are as follows: 
 
 =over 4
@@ -281,10 +275,10 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
  for
 
 
-  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
+  File::PM2File - Convert PM specifications to file specifications
 
 
- Revision: -
+ Revision: A
 
 [snip]
 
@@ -299,7 +293,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
  for
 
 
-  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
+  File::PM2File - Convert PM specifications to file specifications
 
 What we have before, was a totally "failure to communicate." aka Cool Hand Luke. 
 VAR1 was empty. Now VAR1 has something. It is not completely dead.
@@ -407,6 +401,13 @@ absolute file from the
 The module name is now more descriptive
 of the routines in the module.
 
+=item File::PM2File 0.02
+
+Changed prerequisite from "Test::STD::Scrub" to "Text::Scrub".
+This was a change to make the name more descriptive of the contents
+of the program module.
+
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -449,8 +450,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/File-PM2File-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.01
+   http://www.softwarediamonds/packages/File-PM2File-0.02
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.02
 
 
 =item Prerequistes.
@@ -458,7 +459,7 @@ The distribution file is at the following respositories:
  'File::SmartNL' => '0',
  'File::Package' => '0',
  'File::TestPath' => '0',
- 'Test::STD::Scrub' => '0',
+ 'Text::Scrub' => '0',
  'Test::Tech' => '1.08',
 
 
@@ -568,15 +569,19 @@ __DATA__
 DISTNAME: File-PM2File^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.01^
+VERSION : 0.02^
 FREEZE: 1^
-PREVIOUS_DISTNAME: File-FileUtil^
-PREVIOUS_RELEASE: 0.03^
-REVISION: -^
+PREVIOUS_DISTNAME:  ^
+PREVIOUS_RELEASE: 0.01^
+REVISION: A^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
-ABSTRACT: Generic file utilities originally developed to support Test::STDmaker^
-TITLE   :  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker^
+
+ABSTRACT: 
+Convert a Program Module specification
+to the file specification for the current site operating system^
+
+TITLE   :  File::PM2File - Convert PM specifications to file specifications^
 END_USER: General Public^
 COPYRIGHT: copyright  2003 Software Diamonds^
 CLASSIFICATION: NONE^
@@ -593,10 +598,7 @@ COMPRESS: gzip^
 COMPRESS_SUFFIX: gz^
 
 RESTRUCTURE:  ^
-CHANGE2CURRENT:  
-  return if $file =~ s=FileUtil/FileUtil=PM2File=;
-  return if $file =~ s=FileUtil=PM2File=;
-^
+CHANGE2CURRENT:  ^
 
 AUTO_REVISE: 
 lib/File/PM2File.pm
@@ -607,7 +609,7 @@ PREREQ_PM:
 'File::SmartNL' => '0',
 'File::Package' => '0',
 'File::TestPath' => '0',
-'Test::STD::Scrub' => '0',
+'Text::Scrub' => '0',
 'Test::Tech' => '1.08',
 ^
 
@@ -831,6 +833,13 @@ absolute file from the
 The module name is now more descriptive
 of the routines in the module.
 
+\=item File::PM2File 0.02
+
+Changed prerequisite from "Test::STD::Scrub" to "Text::Scrub".
+This was a change to make the name more descriptive of the contents
+of the program module.
+
+
 \=back
 
 ^
